@@ -2,7 +2,7 @@
 test_that("mock db: check output format", {
   cdm <- mockIncidencePrevalenceRef()
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   inc <- estimateIncidence(
     cdm = cdm,
@@ -35,12 +35,11 @@ test_that("mock db: check output format", {
     "denominator_cohort_id",
     "denominator_age_group",
     "denominator_sex",
-    "denominator_days_prior_history",
+    "denominator_days_prior_observation",
     "denominator_start_date",
     "denominator_end_date",
-    "denominator_strata_cohort_definition_id",
-    "denominator_strata_cohort_name",
-    "denominator_closed_cohort",
+    "denominator_target_cohort_definition_id",
+    "denominator_target_cohort_name",
     "cdm_name"
   ) %in%
     names(inc)))
@@ -59,12 +58,11 @@ test_that("mock db: check output format", {
     "denominator_cohort_id",
     "denominator_age_group",
     "denominator_sex",
-    "denominator_days_prior_history",
+    "denominator_days_prior_observation",
     "denominator_start_date",
     "denominator_end_date",
-    "denominator_strata_cohort_definition_id",
-    "denominator_strata_cohort_name",
-    "denominator_closed_cohort",
+    "denominator_target_cohort_definition_id",
+    "denominator_target_cohort_name",
     "cdm_name"
   ) %in%
     names(incidenceAttrition(inc))))
@@ -74,7 +72,7 @@ test_that("mock db: check output format", {
   DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 
   cdm <- mockIncidencePrevalenceRef()
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
   inc <- estimateIncidence(
     cdm = cdm,
     denominatorTable = "denominator",
@@ -128,7 +126,7 @@ test_that("mock db: checks on working example", {
     outcomeTable = outcomeTable
   )
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   inc <- estimateIncidence(
     cdm = cdm,
@@ -138,6 +136,21 @@ test_that("mock db: checks on working example", {
   )
   expect_true(nrow(inc) >= 1)
 
+  # reconnect
+  cdmReconn <- CDMConnector::cdm_from_con(
+    con = attr(cdm, "dbcon"),
+    cohort_tables = c("denominator", "outcome"),
+    write_schema = "main"
+  )
+  inc_recon <- estimateIncidence(
+    cdm = cdmReconn,
+    denominatorTable = "denominator",
+    outcomeTable = "outcome",
+    interval = c("years", "overall")
+  )
+  # expect_equal(inc, inc_recon)
+  # expect_equal(incidenceAttrition(inc), incidenceAttrition(inc_recon))
+
   DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 })
 
@@ -177,7 +190,7 @@ test_that("mock db: check working example 2", {
     outcomeTable = outcomeTable
   )
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   inc <- estimateIncidence(cdm,
     denominatorTable = "denominator",
@@ -272,7 +285,7 @@ test_that("mock db: check study periods", {
     outcomeTable = outcomeTable
   )
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   inc <- estimateIncidence(cdm,
     denominatorTable = "denominator",
@@ -350,7 +363,8 @@ test_that("mock db: check overall", {
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm, cohortDateRange = c(as.Date("2007-01-01"), as.Date(NA))
+    cdm = cdm, name = "denominator",
+    cohortDateRange = c(as.Date("2007-01-01"), as.Date(NA))
   )
 
   inc <- estimateIncidence(cdm,
@@ -429,7 +443,7 @@ test_that("mock db: check person days", {
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm,
+    cdm = cdm, name = "denominator",
     ageGroup = list(c(20, 30))
   )
 
@@ -527,7 +541,7 @@ test_that("mock db: check periods follow calendar dates", {
 
   # startDate during a year (with year as interval)
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm, cohortDateRange = c(as.Date("2010-02-01"), as.Date(NA))
+    cdm = cdm, name = "denominator", cohortDateRange = c(as.Date("2010-02-01"), as.Date(NA))
   )
 
   inc <- estimateIncidence(
@@ -546,7 +560,8 @@ test_that("mock db: check periods follow calendar dates", {
 
   # startDate during a month (with month as interval)
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm, cohortDateRange = c(as.Date("2011-01-15"), as.Date(NA))
+    cdm = cdm, name = "denominator", overwrite = TRUE,
+    cohortDateRange = c(as.Date("2011-01-15"), as.Date(NA))
   )
 
   inc <- estimateIncidence(
@@ -607,7 +622,7 @@ test_that("mock db: check washout windows", {
     outcomeTable = outcomeTable
   )
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   incW0 <- estimateIncidence(cdm,
     denominatorTable = "denominator",
@@ -703,7 +718,7 @@ test_that("mock db: check washout windows", {
     outcomeTable = outcomeTable
   )
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   incW365 <- estimateIncidence(cdm,
     denominatorTable = "denominator",
@@ -754,7 +769,7 @@ test_that("mock db: check events overlapping with start of a period", {
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm,
+    cdm = cdm, name = "denominator",
     ageGroup = list(c(20, 30))
   )
 
@@ -805,7 +820,7 @@ test_that("mock db: check events overlapping with start of a period", {
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm,
+    cdm = cdm, name = "denominator",
     ageGroup = list(c(20, 30))
   )
 
@@ -860,7 +875,7 @@ test_that("mock db: compare results from months and years", {
     outcomeTable = outcomeTable
   )
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm, cohortDateRange = c(as.Date("2010-01-01"), as.Date("2011-12-31"))
+    cdm = cdm, name = "denominator", cohortDateRange = c(as.Date("2010-01-01"), as.Date("2011-12-31"))
   )
 
   incMonths <- estimateIncidence(
@@ -894,7 +909,7 @@ test_that("mock db: compare results from months and years", {
 
   cdm <- mockIncidencePrevalenceRef(sampleSize = 10000)
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm, cohortDateRange = c(as.Date("2010-01-01"), as.Date("2011-12-31"))
+    cdm = cdm, name = "denominator", cohortDateRange = c(as.Date("2010-01-01"), as.Date("2011-12-31"))
   )
 
   incWeeks <- estimateIncidence(
@@ -1000,7 +1015,7 @@ test_that("mock db: check entry and event on same day", {
     outcomeTable = outcomeTable
   )
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   incWithoutRep <- estimateIncidence(
     cdm = cdm,
@@ -1064,7 +1079,7 @@ test_that("mock db: cohort start overlaps with the outcome", {
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm,
+    cdm = cdm, name = "denominator",
     ageGroup = list(c(20, 30))
   )
 
@@ -1119,7 +1134,7 @@ test_that("mock db: check outcome before observation period start", {
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm, cohortDateRange = c(as.Date("2000-01-01"), as.Date("2004-01-01"))
+    cdm = cdm, name = "denominator", cohortDateRange = c(as.Date("2000-01-01"), as.Date("2004-01-01"))
   )
 
   # with rep events - should have both people
@@ -1181,7 +1196,7 @@ test_that("mock db: check outcome before observation period start", {
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm, cohortDateRange = c(as.Date("2000-01-01"), as.Date("2004-01-01"))
+    cdm = cdm, name = "denominator", cohortDateRange = c(as.Date("2000-01-01"), as.Date("2004-01-01"))
   )
 
   # with rep events - should have one person for rep, both people in second
@@ -1243,7 +1258,7 @@ test_that("mock db: check outcome before observation period start", {
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm, cohortDateRange = c(as.Date("2000-01-01"), as.Date("2004-01-01"))
+    cdm = cdm, name = "denominator", cohortDateRange = c(as.Date("2000-01-01"), as.Date("2004-01-01"))
   )
 
   # with rep events - should have both people
@@ -1319,7 +1334,7 @@ test_that("mock db: check minimum counts", {
     observationPeriodTable = observationPeriodTable,
     outcomeTable = outcomeTable
   )
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   inc <- estimateIncidence(
     cdm = cdm,
@@ -1407,7 +1422,7 @@ test_that("mock db: multiple overlapping outcomes", {
     outcomeTable = outcomeTable
   )
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   inc <- estimateIncidence(
     cdm = cdm,
@@ -1462,7 +1477,7 @@ test_that("mock db: multiple overlapping outcomes", {
     outcomeTable = outcomeTable
   )
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   inc <- estimateIncidence(
     cdm = cdm,
@@ -1519,7 +1534,7 @@ test_that("mock db: cohort before period start ending after period", {
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm, cohortDateRange = c(as.Date("2001-01-01"), as.Date("2001-12-31"))
+    cdm = cdm, name = "denominator", cohortDateRange = c(as.Date("2001-01-01"), as.Date("2001-12-31"))
   )
 
   # regardless of washout we expect one event
@@ -1590,7 +1605,7 @@ test_that("mock db: check full period requirement - year", {
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm,
+    cdm = cdm, name = "denominator",
     ageGroup = list(c(20, 30))
   )
 
@@ -1641,7 +1656,7 @@ test_that("mock db: check full period requirement - year", {
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm,
+    cdm = cdm, name = "denominator",
     ageGroup = list(c(20, 30))
   )
 
@@ -1695,7 +1710,7 @@ test_that("mock db: check full period requirement - month", {
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm,
+    cdm = cdm, name = "denominator",
     ageGroup = list(c(20, 30))
   )
 
@@ -1746,7 +1761,7 @@ test_that("mock db: check full period requirement - month", {
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm,
+    cdm = cdm, name = "denominator",
     ageGroup = list(c(20, 30))
   )
 
@@ -1800,7 +1815,7 @@ test_that("mock db: check completeDatabaseIntervals", {
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm
+    cdm = cdm, name = "denominator"
   )
 
   # full periods required TRUE
@@ -1906,7 +1921,7 @@ test_that("mock db: check insufficient study days", {
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm
+    cdm = cdm, name = "denominator"
   )
 
   # we have less than a year of follow up
@@ -2398,7 +2413,7 @@ test_that("mock db: check messages when vebose is true", {
     outcomeTable = outcomeTable
   )
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   expect_message(estimateIncidence(cdm,
     denominatorTable = "denominator",
@@ -2443,7 +2458,7 @@ test_that("expected errors with mock", {
     outcomeTable = outcomeTable
   )
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   # not a cdm reference
   expect_error(estimateIncidence(
@@ -2475,12 +2490,7 @@ test_that("expected errors with mock", {
   ))
 
 
-  # no outcomes
-  expect_error(estimateIncidence(cdm,
-    outcomeTable = "outcome1",
-    interval = c("months"),
-    denominatorTable = "denominator",
-  ))
+  # outcome definition id doesn't exist in cohort set
   expect_error(estimateIncidence(cdm,
     outcomeTable = "outcome",
     interval = c("months"),
@@ -2564,14 +2574,14 @@ test_that("mock db: multiple observation periods", {
   cdm <- mockIncidencePrevalenceRef(
     personTable = personTable,
     observationPeriodTable = observationPeriodTable,
-    strataTable = conditionX,
+    targetCohortTable = conditionX,
     outcomeTable = outcomeTable
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm,
-    strataTable = "strata",
-    strataCohortId = 1
+    cdm = cdm, name = "denominator",
+    targetCohortTable = "target",
+    targetCohortId = 1
   )
 
   incW0 <- estimateIncidence(cdm,
@@ -2608,14 +2618,14 @@ test_that("mock db: multiple observation periods", {
   cdm <- mockIncidencePrevalenceRef(
     personTable = personTable,
     observationPeriodTable = observationPeriodTable,
-    strataTable = conditionX,
+    targetCohortTable = conditionX,
     outcomeTable = outcomeTable
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm,
-    strataTable = "strata",
-    strataCohortId = 1
+    cdm = cdm, name = "denominator",
+    targetCohortTable = "target",
+    targetCohortId = 1
   )
 
   incW10 <- estimateIncidence(cdm,
@@ -2656,13 +2666,13 @@ test_that("mock db: multiple observation periods", {
   cdm <- mockIncidencePrevalenceRef(
     personTable = personTable,
     observationPeriodTable = observationPeriodTable,
-    strataTable = conditionX,
+    targetCohortTable = conditionX,
     outcomeTable = outcomeTable
   )
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm,
-    strataTable = "strata",
-    strataCohortId = 1
+    cdm = cdm, name = "denominator",
+    targetCohortTable = "target",
+    targetCohortId = 1
   )
   inc_PreWashout <- estimateIncidence(cdm,
     denominatorTable = "denominator",
@@ -2695,14 +2705,14 @@ test_that("mock db: multiple observation periods", {
   cdm <- mockIncidencePrevalenceRef(
     personTable = personTable,
     observationPeriodTable = observationPeriodTable,
-    strataTable = conditionX,
+    targetCohortTable = conditionX,
     outcomeTable = outcomeTable
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm,
-    strataTable = "strata",
-    strataCohortId = 1
+    cdm = cdm, name = "denominator",
+    targetCohortTable = "target",
+    targetCohortId = 1
   )
 
   inc_Mult1_W0 <- estimateIncidence(cdm,
@@ -2762,14 +2772,14 @@ test_that("mock db: multiple observation periods", {
   cdm <- mockIncidencePrevalenceRef(
     personTable = personTable,
     observationPeriodTable = observationPeriodTable,
-    strataTable = conditionX,
+    targetCohortTable = conditionX,
     outcomeTable = outcomeTable
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm,
-    strataTable = "strata",
-    strataCohortId = 1
+    cdm = cdm, name = "denominator",
+    targetCohortTable = "target",
+    targetCohortId = 1
   )
 
   inc_PreWashEv <- estimateIncidence(cdm,
@@ -2854,14 +2864,14 @@ test_that("mock db: multiple observation periods", {
   cdm <- mockIncidencePrevalenceRef(
     personTable = personTable,
     observationPeriodTable = observationPeriodTable,
-    strataTable = conditionX,
+    targetCohortTable = conditionX,
     outcomeTable = outcomeTable
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm,
-    strataTable = "strata",
-    strataCohortId = 1
+    cdm = cdm, name = "denominator",
+    targetCohortTable = "target",
+    targetCohortId = 1
   )
 
   inc_3op <- estimateIncidence(cdm,
@@ -2900,7 +2910,7 @@ test_that("mock db: check confidence intervals", {
     sampleSize = 10000
   )
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm,
+    cdm = cdm, name = "denominator",
     cohortDateRange = c(as.Date("2008-01-01"), as.Date("2011-01-01"))
   )
   inc <- estimateIncidence(cdm,
@@ -2929,7 +2939,7 @@ test_that("mock db: check attrition", {
   skip_on_cran()
   cdm <- mockIncidencePrevalenceRef(sampleSize = 10000)
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm,
+    cdm = cdm, name = "denominator",
     sex = c("Male", "Female")
   )
   inc <- estimateIncidence(cdm,
@@ -2998,7 +3008,7 @@ test_that("mock db: check attrition with complete database intervals", {
     outcomeTable = outcomeTable
   )
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
   inc <- estimateIncidence(cdm,
     denominatorTable = "denominator",
     outcomeTable = "outcome",
@@ -3019,7 +3029,7 @@ test_that("mock db: check compute permanent", {
   cdm <- mockIncidencePrevalenceRef(sampleSize = 10000)
   attr(cdm, "write_schema") <- "main"
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
   inc <- estimateIncidence(
     cdm = cdm,
     denominatorTable = "denominator",
@@ -3036,7 +3046,7 @@ test_that("mock db: check compute permanent", {
 
   # using permanent
   cdm <- mockIncidencePrevalenceRef(sampleSize = 10000)
-  cdm <- generateDenominatorCohortSet(cdm = cdm, temporary = FALSE)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
   inc <- estimateIncidence(
     cdm = cdm,
     denominatorTable = "denominator",
@@ -3084,8 +3094,7 @@ test_that("mock db: check participants", {
     ageGroup = list(
       c(0, 50),
       c(51, 100)
-    ),
-    temporary = FALSE
+    )
   )
   inc <- estimateIncidence(
     cdm = cdm,
@@ -3103,13 +3112,14 @@ test_that("mock db: check participants", {
     c(
       "test_dpop",
       "test_inc_participants1",
-      "test_dpop_attrition",
-      "test_dpop_set",
-      "test_dpop_count",
+      # "test_dpop_attrition",
+      # "test_dpop_set",
+      # "test_dpop_count",
       "vocabulary",
       "cdm_source", "outcome", "outcome_set", "outcome_count",
-      "strata",
-      "strata_set", "strata_count",
+      "outcome_attrition",
+      "target",
+      "target_set", "target_count","target_attrition" ,
       "observation_period", "person"
     )))
   expect_true(all(!c(
@@ -3146,7 +3156,6 @@ test_that("mock db: overwriting participants", {
 
   cdm <- generateDenominatorCohortSet(
     cdm = cdm, name = "dpop",
-    temporary = FALSE,
     ageGroup = list(
       c(0, 50),
       c(51, 100)
@@ -3189,7 +3198,7 @@ test_that("mock db: overwriting participants", {
 test_that("mock db: if missing cohort attributes", {
   # missing cohort_set
   cdm <- mockIncidencePrevalenceRef()
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
   attr(cdm$outcome, "cohort_set") <- NULL
   expect_error(estimateIncidence(
     cdm = cdm,
@@ -3201,7 +3210,7 @@ test_that("mock db: if missing cohort attributes", {
 
   # missing cohort_count
   cdm <- mockIncidencePrevalenceRef()
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
   attr(cdm$outcome, "cohort_count") <- NULL
   expect_error(estimateIncidence(
     cdm = cdm,
@@ -3211,3 +3220,32 @@ test_that("mock db: if missing cohort attributes", {
   ))
   DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 })
+
+test_that("mock db: empty outcome cohort", {
+
+  cdm <- mockIncidencePrevalenceRef(sampleSize = 200,
+                                    earliestObservationStartDate = as.Date("2000-01-01"),
+                                    latestObservationStartDate = as.Date("2000-01-01"),
+                                    minDaysToObservationEnd = 365,
+                                    maxDaysToObservationEnd = 365)
+
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
+  cdm$outcome <-  cdm$outcome %>% dplyr::filter(cohort_definition_id == 99)
+
+  expect_no_error(inc <- estimateIncidence(
+    cdm = cdm,
+    denominatorTable = "denominator",
+    outcomeTable = "outcome",
+    interval = "months"
+  ))
+  expect_true(all(!is.na(inc$n_persons)))
+  expect_true(sum(inc$n_events)==0)
+
+  # make sure we also have a confidence interval even in the case of an empty outcome cohort
+  expect_true(all(inc$incidence_100000_pys == 0))
+  expect_true(all(inc$incidence_100000_pys_95CI_lower == 0))
+  expect_true(all(inc$incidence_100000_pys_95CI_upper > 0))
+
+  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
+
+})
