@@ -1,7 +1,7 @@
 
 test_that("mock db: check output format", {
   cdm <- mockIncidencePrevalenceRef() %>%
-    generateDenominatorCohortSet()
+    generateDenominatorCohortSet(name = "denominator")
 
   prev <- estimatePrevalence(
     cdm = cdm,
@@ -20,7 +20,8 @@ test_that("mock db: check output format", {
     "prevalence_95CI_upper",
     "prevalence_start_date",
     "prevalence_end_date",
-    "cohort_obscured",
+    "population_obscured",
+    "cases_obscured",
     "result_obscured",
     "outcome_cohort_id",
     "outcome_cohort_name",
@@ -33,12 +34,11 @@ test_that("mock db: check output format", {
     "denominator_cohort_id",
     "denominator_age_group",
     "denominator_sex",
-    "denominator_days_prior_history",
+    "denominator_days_prior_observation",
     "denominator_start_date",
     "denominator_end_date",
-    "denominator_strata_cohort_definition_id",
-    "denominator_strata_cohort_name",
-    "denominator_closed_cohort",
+    "denominator_target_cohort_definition_id",
+    "denominator_target_cohort_name",
     "cdm_name"
   ) %in%
     names(prev)))
@@ -58,12 +58,11 @@ test_that("mock db: check output format", {
     "denominator_cohort_id",
     "denominator_age_group",
     "denominator_sex",
-    "denominator_days_prior_history",
+    "denominator_days_prior_observation",
     "denominator_start_date",
     "denominator_end_date",
-    "denominator_strata_cohort_definition_id",
-    "denominator_strata_cohort_name",
-    "denominator_closed_cohort",
+    "denominator_target_cohort_definition_id",
+    "denominator_target_cohort_name",
     "cdm_name"
   ) %in%
     names(prevalenceAttrition(prev))))
@@ -74,7 +73,7 @@ test_that("mock db: check output format", {
 
 
   cdm <- mockIncidencePrevalenceRef()
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   prev <- estimatePrevalence(
     cdm = cdm,
@@ -131,7 +130,7 @@ test_that("mock db: checks on working example", {
     outcomeTable = outcomeTable
   )
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   prev <- estimatePrevalence(
     cdm = cdm,
@@ -180,7 +179,7 @@ test_that("mock db: working examples 2", {
     outcomeTable = outcomeTable
   )
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm
+    cdm = cdm, name = "denominator"
   )
 
   prev <- estimatePrevalence(cdm,
@@ -235,7 +234,7 @@ test_that("mock db: check outcome lookback", {
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm, cohortDateRange = c(as.Date("2006-01-01"), as.Date("2010-12-31"))
+    cdm = cdm, name = "denominator", cohortDateRange = c(as.Date("2006-01-01"), as.Date("2010-12-31"))
   )
 
   # without look back we´ll only include ongoing outcomes
@@ -359,7 +358,7 @@ test_that("mock db: check minimum counts", {
     outcomeTable = outcomeTable
   )
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   prev <- estimatePrevalence(
     cdm = cdm,
@@ -391,7 +390,7 @@ test_that("mock db: check minimum counts", {
   )
   expect_true(prev$n_cases[1] == 17)
   expect_true(is.na(prev$n_cases[2]))
-  expect_true(is.na(prev$n_cases[3]))
+  expect_true(!is.na(prev$n_cases[3])) # don't suppress zero
   expect_true(prev$n_population[1] == 20)
   expect_true(is.na(prev$n_population[2]))
   expect_true(is.na(prev$n_population[3]))
@@ -444,7 +443,7 @@ test_that("mock db: check study time periods", {
     outcomeTable = outcomeTable
   )
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   prev <- estimatePrevalence(cdm,
     denominatorTable = "denominator",
@@ -506,7 +505,7 @@ test_that("mock db: check study time periods", {
     outcomeTable = outcomeTable
   )
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   prev <- estimatePrevalence(cdm,
     denominatorTable = "denominator",
@@ -581,7 +580,7 @@ test_that("mock db: check fullContribution requirement", {
     outcomeTable = outcomeTable
   )
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm
+    cdm = cdm, name = "denominator"
   )
 
   prev <- estimatePrevalence(cdm,
@@ -659,7 +658,7 @@ test_that("mock db: check periods follow calendar dates", {
   # but if FALSE we should go from 2011 to 2012
   # for yearly incidence
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm
+    cdm = cdm, name = "denominator"
   )
   prev1 <- estimatePrevalence(cdm,
     denominatorTable = "denominator",
@@ -689,7 +688,8 @@ test_that("mock db: check periods follow calendar dates", {
 
   # for months
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm, cohortDateRange = c(as.Date("2011-01-15"), as.Date(NA))
+    cdm = cdm, name = "denominator", overwrite = TRUE,
+    cohortDateRange = c(as.Date("2011-01-15"), as.Date(NA))
   )
 
   # where we expect the study to start on 2011-01-15
@@ -766,7 +766,7 @@ test_that("mock db: check multiple outcome ids", {
     outcomeTable = outcomeTable
   )
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm
+    cdm = cdm, name = "denominator"
   )
 
   prev <- estimatePrevalence(cdm,
@@ -812,7 +812,7 @@ test_that("mock db: some empty result sets", {
     outcomeTable = outcomeTable
   )
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm
+    cdm = cdm, name = "denominator"
   )
 
   prev <- estimatePrevalence(cdm,
@@ -851,7 +851,7 @@ test_that("mock db: check messages when vebose is true", {
 
   cdm <- mockIncidencePrevalenceRef(outcomeTable = outcomeTable)
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   expect_message(estimatePrevalence(cdm,
     denominatorTable = "denominator",
@@ -903,7 +903,7 @@ test_that("mock db: check expected errors", {
     outcomeTable = outcomeTable
   )
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   expect_error(estimatePrevalence(
     cdm = "a",
@@ -930,7 +930,7 @@ test_that("mock db: check user point prevalence function", {
   skip_on_cran()
   cdm <- mockIncidencePrevalenceRef()
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   prev <- estimatePrevalence(
     cdm = cdm,
@@ -954,7 +954,7 @@ test_that("mock db: check user period prevalence function", {
   skip_on_cran()
   cdm <- mockIncidencePrevalenceRef()
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
 
   prev <- estimatePrevalence(
     cdm = cdm,
@@ -1048,14 +1048,14 @@ test_that("mock db: multiple observation periods", {
   cdm <- mockIncidencePrevalenceRef(
     personTable = personTable,
     observationPeriodTable = observationPeriodTable,
-    strataTable = conditionX,
+    targetCohortTable = conditionX,
     outcomeTable = outcomeTable
   )
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm,
-    strataTable = "strata",
-    strataCohortId = 1
+    cdm = cdm, name = "denominator",
+    targetCohortTable = "target",
+    targetCohortId = 1
   )
 
   # should expect for period prevalence monthly 3 times with n_cases 1,
@@ -1111,7 +1111,7 @@ test_that("mock db: check confidence intervals", {
   skip_on_cran()
   cdm <- mockIncidencePrevalenceRef(sampleSize = 10000)
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm
+    cdm = cdm, name = "denominator"
   )
   prev <- estimatePrevalence(cdm,
     denominatorTable = "denominator",
@@ -1141,7 +1141,7 @@ test_that("mock db: check attrition", {
   skip_on_cran()
   cdm <- mockIncidencePrevalenceRef(sampleSize = 10000)
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm,
+    cdm = cdm, name = "denominator",
     sex = c("Male", "Female")
   )
   prev <- estimatePrevalence(cdm,
@@ -1212,10 +1212,8 @@ test_that("mock db: check attrition with complete database intervals", {
     outcomeTable = outcomeTable
   )
 
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
-
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm
+    cdm = cdm, name = "denominator"
   )
   prev <- estimatePrevalence(cdm,
     denominatorTable = "denominator",
@@ -1260,8 +1258,7 @@ test_that("mock db: check compute permanent", {
   attr(cdm, "write_schema") <- "main"
 
   cdm <- generateDenominatorCohortSet(
-    cdm = cdm, name = "dpop",
-    temporary = FALSE
+    cdm = cdm, name = "dpop"
   )
   prev <- estimatePrevalence(
     cdm = cdm,
@@ -1315,18 +1312,17 @@ test_that("mock db: check participants", {
   skip_on_cran()
 
   cdm <- mockIncidencePrevalenceRef(sampleSize = 10000)
-  attr(cdm, "write_schema") <- "main"
   attr(cdm, "write_prefix") <- "test_"
 
   cdm <- generateDenominatorCohortSet(
     cdm = cdm, name = "dpop",
-    temporary = FALSE,
     sex = c("Male", "Female", "Both"),
     ageGroup = list(
       c(0, 50),
       c(51, 100)
     )
   )
+
   prev <- estimatePrevalence(
     cdm = cdm,
     denominatorTable = "dpop",
@@ -1342,13 +1338,14 @@ test_that("mock db: check participants", {
     c(
       "test_dpop",
       "test_point_prev_participants1",
-      "test_dpop_attrition",
-      "test_dpop_set",
-      "test_dpop_count",
+      # "test_dpop_attrition",
+      # "test_dpop_set",
+      # "test_dpop_count",
       "vocabulary",
       "cdm_source", "outcome", "outcome_set", "outcome_count",
-      "strata",
-      "strata_set", "strata_count",
+      "outcome_attrition", "outcome_set",
+      "target","target_attrition" ,
+      "target_set", "target_count",
       "observation_period", "person"
     )))
   expect_true(all(!c(
@@ -1390,7 +1387,6 @@ test_that("mock db: overwriting participants", {
 
   cdm <- generateDenominatorCohortSet(
     cdm = cdm, name = "dpop",
-    temporary = FALSE,
     ageGroup = list(
       c(0, 50),
       c(51, 100)
@@ -1433,7 +1429,7 @@ test_that("mock db: overwriting participants", {
 test_that("mock db: if missing cohort attributes", {
   # missing cohort_set
   cdm <- mockIncidencePrevalenceRef()
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
   attr(cdm$outcome, "cohort_set") <- NULL
   expect_error(estimatePrevalence(
     cdm = cdm,
@@ -1445,7 +1441,7 @@ test_that("mock db: if missing cohort attributes", {
 
   # missing cohort_count
   cdm <- mockIncidencePrevalenceRef()
-  cdm <- generateDenominatorCohortSet(cdm = cdm)
+  cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
   attr(cdm$outcome, "cohort_count") <- NULL
   expect_error(estimatePrevalence(
     cdm = cdm,
